==> v0.2.0.910.zip: lidarr/src/NzbDrone.Core/NetImport/NetImportBase.cs <==
﻿using System;
using System.Collections.Generic;
using FluentValidation.Results;
using NLog;
using NzbDrone.Core.Configuration;
using NzbDrone.Core.Parser;
using NzbDrone.Core.ThingiProvider;
using NzbDrone.Core.Tv;

namespace NzbDrone.Core.NetImport
{
    public abstract class NetImportBase<TSettings> : INetImport
        where TSettings : IProviderConfig, new()
    {
        protected readonly IConfigService _configService;
        protected readonly IParsingService _parsingService;
        protected readonly Logger _logger;

        public abstract string Name { get; }
        public abstract bool Enabled { get; }
        public abstract bool EnableAuto { get; }

        public abstract IList<Movie> Fetch();

        public NetImportBase(IConfigService configService, IParsingService parsingService, Logger logger)
        {
            _configService = configService;
            _parsingService = parsingService;
            _logger = logger;
        }

        public Type ConfigContract => typeof(TSettings);

        public virtual ProviderMessage Message => null;

        public virtual IEnumerable<ProviderDefinition> GetDefaultDefinitions()
        {
            var config = (IProviderConfig)new TSettings();

            yield return new NetImportDefinition
            {
                Name = this.Name,
                Enabled = config.Validate().IsValid && Enabled,
                EnableAuto = true,
                ProfileId = 1,
                MinimumAvailability = MovieStatusType.Announced,
                Implementation = GetType().Name,
                Settings = config
            };
        }

        public virtual ProviderDefinition Definition { get; set; }

        public virtual object RequestAction(string action, IDictionary<string, string> query) { return null; }

        protected TSettings Settings => (TSettings)Definition.Settings;

        public ValidationResult Test()
        {
            var failures = new List<ValidationFailure>();

            try
            {
                Test(failures);
            }
            catch (Exception ex)
            {
                _logger.Error(ex, "Test aborted due to exception");
                failures.Add(new ValidationFailure(string.Empty, "Test was aborted due to an error: " + ex.Message));
            }

            return new ValidationResult(failures);
        }

        protected abstract void Test(List<ValidationFailure> failures);

        public override string ToString()
        {
            return Definition.Name;
        }

    }
}

==> v0.2.0.995.zip: lidarr/src/NzbDrone.Core/NetImport/NetImportBase.cs <==
﻿using System;
using System.Collections.Generic;
using FluentValidation.Results;
using NLog;
using NzbDrone.Core.Configuration;
using NzbDrone.Core.Parser;
using NzbDrone.Core.ThingiProvider;
using NzbDrone.Core.Tv;

namespace NzbDrone.Core.NetImport
{
    public class NetImportFetchResult
    {
        public IList<Movie> Movies { get; set; }
        public bool AnyFailure { get; set; }
    }
    
    public abstract class NetImportBase<TSettings> : INetImport
        where TSettings : IProviderConfig, new()
    {
        protected readonly IConfigService _configService;
        protected readonly IParsingService _parsingService;
        protected readonly Logger _logger;

        public abstract string Name { get; }
        public abstract bool Enabled { get; }
        public abstract bool EnableAuto { get; }

        public abstract NetImportFetchResult Fetch();

        public NetImportBase(IConfigService configService, IParsingService parsingService, Logger logger)
        {
            _configService = configService;
            _parsingService = parsingService;
            _logger = logger;
        }

        public Type ConfigContract => typeof(TSettings);

        public virtual ProviderMessage Message => null;

        public virtual IEnumerable<ProviderDefinition> GetDefaultDefinitions()
        {
            var config = (IProviderConfig)new TSettings();

            yield return new NetImportDefinition
            {
                Name = this.Name,
                Enabled = config.Validate().IsValid && Enabled,
                EnableAuto = true,
                ProfileId = 1,
                MinimumAvailability = MovieStatusType.Announced,
                Implementation = GetType().Name,
                Settings = config
            };
        }

        public virtual ProviderDefinition Definition { get; set; }

        public virtual object RequestAction(string action, IDictionary<string, string> query) { return null; }

        protected TSettings Settings => (TSettings)Definition.Settings;

        public ValidationResult Test()
        {
            var failures = new List<ValidationFailure>();

            try
            {
                Test(failures);
            }
            catch (Exception ex)
            {
                _logger.Error(ex, "Test aborted due to exception");
                failures.Add(new ValidationFailure(string.Empty, "Test was aborted due to an error: " + ex.Message));
            }

            return new ValidationResult(failures);
        }

        protected abstract void Test(List<ValidationFailure> failures);

        public override string ToString()
        {
            return Definition.Name;
        }

    }
}
